@@ -2,10 +2,12 @@ use strict;
 use warnings;
 package A1z::HTML5::Template;
 
-# ABSTRACT: Fast/easy HTML5 apps/pages in Perl
+# ABSTRACT: Fast/easy Web Apps in Perl
 
 
-our $VERSION = '0.09';
+our $NAME = "Fast and Easy Web Apps ";
+
+our $VERSION = '0.10';
 
 
 
@@ -431,7 +433,7 @@ sub body_topnavbar
 	my %in;
 	
 	%in = (
-		file => "https://secure.bislinks.com/js/utils/top-nav-bar.js",
+		file => "https://www.a1z.us/js/utils/top-nav-bar.js",
 		name => "Menu",
 		@_,
 	);
@@ -472,7 +474,7 @@ sub head_js_css
 	<!-- Bootstrap/jqueryUI -->
 
 	<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-	<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+	<link href="https://www.a1z.us/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
 	<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
 
 	<!--HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries-->
@@ -933,16 +935,23 @@ sub html_bootstrap_css
 {
 	return qq{<!-- Bootstrap/jqueryUI -->
 <link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-};  
+<link href="https://www.a1z.us/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+};
+  
 }
 
+
+
+
 sub html_jqueryui_css 
 {
-	# jquery ui theme 1.12.0
+	# jquery ui theme jquery-ui.css #1.12.0
 	return qq{<link href="https://code.jquery.com/ui/1.12.0/themes/smoothness/jquery-ui.css" rel="stylesheet">}; 
 }
 
+
+
+
 sub html_shim_respond 
 {
 	return qq{<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
@@ -954,24 +963,28 @@ sub html_shim_respond
 
 }
 
+
+
 sub html_navbar 
 {
 	#my $self = shift; 
+
+	#serverName, pageName, menuName, dropDownLinks
 	
-	my %i;
-	%i = (
-		-nbmenu 	=>	"", 
-		-nbpage 	=> 	"",
-		-nbpage1    =>  "",
-		-nbmenu1    =>  "",
+	my %in;
+	%in = (
+		-nbMenuName 	=>	"", 
+		-nbPageName 	=> 	"",
+		-nbServer    =>  "",
+		-nbLinks => "blog-support-help-contact-sale"
 		@_,		
 	);
 	
-	return qq{<script src="/jquery/top-nav-bar.js"></script>
+	return qq{<script src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
 <!--top nav bar begin-->
 <script>
 //<-- 
-fixed_top_navbar('$_[0]', '', '$_[1]', '', '');
+fixed_top_navbar('$in{-nbServer}', '$in{-nbPageName}', '$in{-nbMenuName}', '$in{-nbLinks}');
 //-->
 </script>
 <!-- top nav bar end--> 
@@ -980,18 +993,15 @@ fixed_top_navbar('$_[0]', '', '$_[1]', '', '');
 }
 
 
+ 
+
 sub html_bootstrap_js  
 {
 	# jquery:3.3.0 ui:1/12/1
+
 	return qq{<!-- Bootstrap/jqueryUI -->
-<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
-<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
-<!--[if lt IE 9]>
-<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
-<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
-<![endif]-->
+<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js" rel="stylesheet" type="text/css">
+
 }; 
 
 }
@@ -1006,6 +1016,9 @@ sub html_jquery
 	
 }
 
+
+
+
 sub html_humanejs_css
 {
 	return qq{<link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/bigbox.css'>
@@ -1018,8 +1031,12 @@ sub html_humanejs_css
 <link href='http://fonts.googleapis.com/css?family=Ubuntu+Mono' rel='stylesheet' type='text/css'>
 <link href='http://fonts.googleapis.com/css?family=Cabin+Sketch:700&v2' rel='stylesheet' type='text/css'>
 }; 
+
 }
 
+
+
+
 sub html_bootstrap_bluimp 
 {
 	return qq{<!-- The Bootstrap Image Gallery lightbox, should be a child element of the document body -->
@@ -1060,6 +1077,9 @@ sub html_bootstrap_bluimp
 }
 # end sub html_bootstrap_bluimp 
 
+
+
+
 sub head 
 {
 	my $self = shift; 
@@ -1072,11 +1092,12 @@ sub head
 		-jqueryui 	=> html_jqueryui_css, 
 		-htmlshim	=> html_shim_respond, 
 		-humanejs  => html_humanejs_css, 
-		-title 		=> "Page Title", 
-		-cssLinks => "", 
+		-title 		=> "$ENV{SERVER_NAME}" || "", 
+		-cssLinks => "https://www.a1z.us/A1z/HTML5/Template.css", 
 		-cssCode => "", 
 		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
-<meta name="viewport" content="width=device-width, initial-scale=1.0">}, 
+<meta name="viewport" content="width=device-width, initial-scale=1.0">
+}, 
 		-charsetmeta => qq{<meta charset="utf-8">}, 
 		-usermeta => "",
 		@_,
@@ -1155,7 +1176,7 @@ sub body
 		-defaultjquery => qq{$HTML{-defaultjquery}}, 
 		-humanejs => qq{<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/humane.min.js">},
 		-userjquery => qq{}, 
-		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, "Obselete Thu Mar 26 10:03:47 2015") , 
+		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, " ") , 
 		-content => qq{<div class="content">Content</div>}, 
 		-footer => qq{All rights reserved &copy; $ENV{SERVER_NAME}}, 	
 		-bootstrapbluimp => html_bootstrap_bluimp, 	
@@ -1164,7 +1185,7 @@ sub body
 	
 	return qq{<body onload="$in{-onload}">
 <div id="main" class="container">
-		<script type="text/javascript" src="https://secure.bislinks.com/jquery/utils/top-nav-bar.js"></script>
+		<script type="text/javascript" src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
 <!--top nav bar begin-->
 <script type="text/javascript">
 //<-- 
@@ -1223,6 +1244,7 @@ sub create_accordion
 
 
 
+
 sub open_file 
 {
 	my $self =shift;
@@ -1600,6 +1622,7 @@ sub edit_file
 }
 
 
+
 sub write_file
 {
 	my $self = shift;
@@ -1699,6 +1722,15 @@ sub write_file
 	
 }
 
+# end write_file
+
+
+
+
+
+
+
+
 
 
 
@@ -1712,30 +1744,48 @@ __END__
 
 =head1 NAME
 
-A1z::HTML5::Template - Fast/easy HTML5 apps/pages in Perl
+A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
     use A1z::HTML5::Template;
     my $foo = A1z::HTML5::Template->new();
 
-    use lib '/home/user/path/to/app';
+    This directory should be writable by the web server, required to create/hold page content files.
+	This may also contain your custom JavaScript/CSS libraries.
+	Works for both Windows and Linux
+	
+		use lib '/home/user/path/to/app';
+		or
+		use lib 'C:/Inetpub/wwwroot/path/to/app';
 
 	# for features like 'say'
 	use 5.10.0;
 
 	my $h = A1z::HTML5::Template->new(); 
 
+	Fast, Easy, and Simple: Just Two Lines!
+	
+		say $h->head( -title => "My Brand Name" );
+		say $h->body( -content => qq{ Coming Soon });
+
+	For More Control/Customization: Not for the lazy!
+	
 	say $h->header('utf8');  
 	say $h->start_html(); 
 	say $h->head_title("My New App"); 
 	say $h->head_meta(); 
+
+	Load basic/required JavaScript/CSS libraries
 	say $h->head_js_css(); 
+
+	Add your own custom JavaScript/CSS files
 	say $h->head_js_css('/url/to/app/Template.css'); 
+
 	say $h->end_head(); 
 	say $h->begin_body();
 
@@ -1743,29 +1793,32 @@ version 0.09
 
 	say qq{<main class="container">}; 
 
-	# output file content as menu
-	say $h->body_accordion( $h->open_file("/home/user/path/to/app/open_file_example.txt", 'menu', 'Menu') ); 
+		# output file content as menu
+		say $h->body_accordion( $h->open_file("/home/user/path/to/app/open_file_example.txt", 'menu', 'Menu') ); 
 
-	# as a HTML5 table 
-	say $h->body_accordion( $h->open_file("$sys{cgibase}/open_file_example.txt", 'table', 'Table Header') );
+		# as a HTML5 table 
+		say $h->body_accordion( $h->open_file("$sys{cgibase}/open_file_example.txt", 'table', 'Table Header') );
 		
-	# math works 
-	say $h->body_article( header => "Simple Mathematics", content => $h->math1("2", "4") );
+		# Simple mathematics 
+		say $h->body_article( header => "Simple Mathematics", content => $h->math1("2", "4") );
 
-	# math works 
-	say $h->body_article( header => "Times Table", content => $h->timestable("2") );
-
-	# Both body_accordion and body_article are used synonymously and do the same thing but with little variations.
+		# Times Table  
+		say $h->body_article( header => "Times Table", content => $h->timestable("2") );
 
 	say qq{</main>};
 
-	say $h->body_js_css(); 
+	Required/Default JavaScript libraries.
+		say $h->body_js_css(); 
+	
+	Add your own JavaScript libraries:
+		say $h->body_js_css("complete-url_or_path-to-js-css-libraries")	
+
 	say $h->end_body();
 	say $h->end_html(); 
 
 =head1 NAME
 
-	A1z::HTML5::Template is a perl implementation of customizable HTML5 tags.
+	"A1z::HTML5::Template" provides customizable HTML5 tags for creating "Fast and Easy Web Apps."
 
 =head1 Installation
 
@@ -1775,7 +1828,7 @@ version 0.09
 
 =head1 VERSION
 
-	Version 0.09
+	Version 0.10
 
 =head1 METHODS
 
@@ -1806,9 +1859,13 @@ version 0.09
 
 	Provides doctype html
 	
-	$h->start_html();
+	Default includes utf-8
+
+		$h->start_html();
 	
-	$h->start_html('utf8');
+	Or, add your own charset to your app:
+
+		$h->start_html('DifferentCharset');
 
 =head2 body_js_css
 
@@ -1855,7 +1912,7 @@ version 0.09
 
 	Provides top nav bar optionally.
 	
-	By default it is loaded from secure.bislinks.com which probably be removed in a future version.
+	By default it is loaded from www.a1z.us which probably be removed in a future version.
 	So, get a copy from bootstrap 3 and store it on your server.
 
 =head2 head_js_css
@@ -1867,7 +1924,7 @@ version 0.09
 		Default includes the following:
 		
 			bootstrap 3.3.0 .css from maxcdn 
-			navbar-fixed-top.css from secure.bislinks.com
+			navbar-fixed-top.css from www.a1z.us
 			jquery 1.12.1 smoothness theme from code.jquery.com 
 			Shim and Respond.js from maxcdn 
 	
@@ -1922,18 +1979,143 @@ version 0.09
 
 =head1 HTML Hash
 
-	Default HTML used in default_*
+	Default HTML used in default_* for internal use only.
 
 =head2 html_bootstrap_css 
 
-=head1 AUTHOR
+	Used in $h->head and $h->body internally.
 
-Sudheer Murthy, C<< <pause at a1z.us> >>
+	All methods starting with 'html_' are used internally!
+
+	Include bootstrap.min.css, #3.3.0 from maxcdn and navbar-fixed-top.css from a1z.us
+		
+		$h->html_bootstrap_css()
+
+=head2 html_jqueryui_css
+
+	Includes jquery ui theme jquery-ui.css #1.12.0
+
+=head2 html_shim_respond
+
+	html5shiv.min.js   #3.7.2
+	respond.min.js     #1.4.2
+
+=head2 html_navbar
+
+	Customizations for top-nav-bar.js from a1z.us
+
+	$h->html_navbar(
+		-nbMenuName => "menuName", 
+		-nbPageName => "pageName", 
+		-nbServer => "serverName", 
+		-nbLinks => "dropDownLinks: URLs separated by a dash, mostly relative URLs. E.g., blog-support-help-contact-sale"
+	);
+
+=head2 html_bootstrap_js
+
+	bootstrap.min.js, #3.3.0, from maxcdn
+
+=head2 html_humanejs_css
+
+	humane-js #3.2.2 cdnjs.cloudflare
+	fonts.googleapis.com
+
+=head2 html_bootstrap_bluimp
+
+	bootstrap gallery lightbox - content for <body>
+
+	&html_bootstrap_bluimp;
+
+	for internal use. 
+
+=head2 head
+
+	$h->head();
+
+	For use in Fast/Easy Web App - E.g., in under construction web sites.
+
+=head2 body
+
+	$h->body();
+
+	For use in Fast/Easy Web App - E.g., in under construction web sites.
+
+=head2 create_accordion
+
+	$h->create_accordion("path/to/file/containing/accordion/elements");
+
+	Uses open_file to load "file"
+
+=head2 open_file
+
+	Used for loading all kinds of custom elements for different output formats stored in simple text files.
+
+	$h->open_file("path/to/file", "outputFormat", "outputHeader");
+
+	$h->open_file("C:/Inetpub/wwwroot/MyApp/menu.txt", "menu", "Menu");
+
+	This is the heart of the App, A1z::HTML5::Template, quite a long sub/method comprising of about 292 lines including empty lines. 
+
+=head2 edit_file
+
+	Edit your app/page/site. Customize HTML produced by A1z::HTML5::Template. 
+
+	Creates a form to edit contents of a file. 
+
+	The contents of this file should be in a special format. See open_file_example.txt. 
+
+	Data is stored in simple text files in the app's home dir.  
+
+	We recommend creating a new file for editing/writing purpose; E.g., "TemplateAdmin.cgi"
+
+	use lib '/path/to/app';
+
+	use A1z::HTML5::Template;
+	my $h = A1z::HTML5::Template->new();
+
+	say $h->header('utf8');
+	say $h->start_html(); 
+	say $h->head_title("Edit App"); 
+	say $h->head_meta();
+	say $h->head_js_css();  
+	say $h->end_head(); 
+	say $h->begin_body();
+
+	# Show edit form
+
+ 	say $h->body_article( 
+
+		header => "Edit page items", 
+
+		action => "TemplateAdmin.cgi",
+
+		content => $h->edit_file( file => "/absolute/path/to/app/open_file_example.txt") 
+	);
+
+	# Save Customizations to file.
+
+	# include write_file if you submit form to the same file ( TemplateAdmin.cgi )
+
+	say $h->body_article( 
+
+		header => "<a href='$sys{cgiurl}/TemplateAdmin.cgi' title='Refresh to get the latest/saved content'>Refresh</a> ", 
+
+		content => $h->write_file( file => "/absolute/path/to/app/open_file_example.txt")
+	 
+	);
+
+	say $h->body_js_css(); 
+	say $h->end_body();
+	say $h->end_html(); 
+
+=head2 write_file
+
+	See documentation for 'edit_file.'
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-html5-template at rt.cpan.org>, or through
-the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML5-Template>.  I will be notified, and then you'll
+Please report any bugs or feature requests to C<bug-a1z-html5-template at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=A1z-HTML5-Template>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -1948,24 +2130,26 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML5-Template>
+L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=A1z-HTML5-Template>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/HTML5-Template>
+L<http://annocpan.org/dist/A1z-HTML5-Template>
 
 =item * CPAN Ratings
 
-L<https://cpanratings.perl.org/d/HTML5-Template>
+L<https://cpanratings.perl.org/d/A1z-HTML5-Template>
 
 =item * Search CPAN
 
-L<https://metacpan.org/release/HTML5-Template>
+L<https://metacpan.org/release/A1z-HTML5-Template>
 
 =back
 
 =head1 ACKNOWLEDGEMENTS
 
+	I am greatly indebted to my family for letting me be 'addicted' and 'married' to my computers.
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2018 Sudheer Murthy.
